# Security Policy

## Supported Versions

We will continue to resolve the following vulnerability alerts by GitHub until the version 1.x releases:

- Dependabot
- Code scanning
- Secret scanning alerts

| Version |     Supported      |
|---------|:------------------:|
| 0.1.x   | :white_check_mark: |

## Reporting a Vulnerability

To report a security issue, visit GitHub Security Advisories and submit details.

https://github.com/fairy-select/chronovoyage/security/advisories/new
